==> keyclic_sdk_api-2.1.0.tar.gz: lib/model/member_embedded.dart <==
part of keyclic_sdk_api.api;

class MemberEmbedded {
  MemberEmbedded({
    this.availableRoles,
  });

  MemberEmbedded.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    if (json['availableRoles'] is List) {
      availableRoles = List<String>.from(json['availableRoles']);
    }
  }

  List<String> availableRoles;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is MemberEmbedded &&
        runtimeType == other.runtimeType &&
        DeepCollectionEquality.unordered()
            .equals(availableRoles, other.availableRoles);
  }

  /// By default hashCode return reference
  @override
  int get hashCode {
    int hashCode = 0;

    if (availableRoles is List && availableRoles.isNotEmpty) {
      hashCode ^= availableRoles
          .map((String element) => element.hashCode)
          .reduce((int value, int cursor) => value ^ cursor);
    }

    return hashCode;
  }

  static List<MemberEmbedded> listFromJson(List<dynamic> json) {
    return json == null
        ? <MemberEmbedded>[]
        : json.map((dynamic value) => MemberEmbedded.fromJson(value)).toList();
  }

  static Map<String, MemberEmbedded> mapFromJson(Map<String, dynamic> json) {
    var map = Map<String, MemberEmbedded>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = MemberEmbedded.fromJson(value));
    }

    return map;
  }

  Map<String, dynamic> toJson() {
    return {
      'availableRoles': availableRoles,
    };
  }

  @override
  String toString() {
    return 'MemberEmbedded[availableRoles=$availableRoles, ]';
  }
}

==> keyclic_sdk_api-2.1.28.tar.gz: lib/model/member_embedded.dart <==
part of keyclic_sdk_api.api;

class MemberEmbedded {
  MemberEmbedded({
    this.availableRoles,
  });

  MemberEmbedded.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    if (json['availableRoles'] is List) {
      availableRoles = List<String>.from(json['availableRoles']);
    }
  }

  List<String> availableRoles;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is MemberEmbedded &&
        runtimeType == other.runtimeType &&
        DeepCollectionEquality.unordered()
            .equals(availableRoles, other.availableRoles);
  }

  /// By default hashCode return reference
  @override
  int get hashCode {
    int hashCode = 0;

    if (availableRoles is List && availableRoles.isNotEmpty) {
      hashCode ^= availableRoles
          .map((String element) => element.hashCode)
          .reduce((int value, int cursor) => value ^ cursor);
    }

    return hashCode;
  }

  static List<MemberEmbedded> listFromJson(List<dynamic> json) {
    return json == null
        ? <MemberEmbedded>[]
        : json.map((dynamic value) => MemberEmbedded.fromJson(value)).toList();
  }

  static Map<String, MemberEmbedded> mapFromJson(Map<String, dynamic> json) {
    var map = Map<String, MemberEmbedded>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = MemberEmbedded.fromJson(value));
    }

    return map;
  }

  Map<String, dynamic> toJson() {
    return {
      if (availableRoles != null) 'availableRoles': availableRoles,
    };
  }

  @override
  String toString() {
    return 'MemberEmbedded[availableRoles=$availableRoles, ]';
  }
}
